@@ -1,5 +1,5 @@
 // runnerline_instructions.cpp
-// Revision 7-feb-2005
+// Revision 24-apr-2009
 
 #include "runnerline_impl.h"
 
@@ -24,6 +24,7 @@ using std::cerr;
 using std::endl;
 using std::flush;
 
+#include <string.h>
 #include <time.h>
 
 #include <cassert>
